@@ -27,12 +27,19 @@ get_test_idata_tsv_with_metadata <- function(schema = c("cdr3_aa", "v_call")) {
 }
 
 #' Get test datasets from `immundata`
-#'
+#' @keywords internal
 #' @export
 get_test_idata <- function() {
   get_test_idata_tsv_with_metadata()
 }
 
+#' Get test datasets from `immundata`
+#' @keywords internal
+#' @export
+get_test_immundata <- function() {
+  get_test_idata_tsv_with_metadata()
+}
+
 get_test_idata_tsv_metadata <- function() {
   md_path <- system.file("extdata/tsv", "metadata_samples.tsv", package = "immundata")
 
